from setuptools import setup, find_packages

setup(
    name="diamondsBySummer",
    version="0.1.1",
    packages=find_packages(),
    install_requires=[],  # Add dependencies here if needed
    author="Rishi",
    description="diamonds by summer",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)

